'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = float;

var _add_sign_to_formatted_number = require('./add_sign_to_formatted_number');

var _add_sign_to_formatted_number2 = _interopRequireDefault(_add_sign_to_formatted_number);

var _coerce_to_number = require('../../number/coerce_to_number');

var _coerce_to_number2 = _interopRequireDefault(_coerce_to_number);

var _const = require('../const');

var _const2 = _interopRequireDefault(_const);

var _const3 = require('../../reg_exp/const');

var _coerce_to_string = require('../../string/coerce_to_string');

var _coerce_to_string2 = _interopRequireDefault(_coerce_to_string);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Formats a float type according to specifiers.
 *
 * @ignore
 * @param  {string} replacement The string to be formatted.
 * @param  {ConversionSpecification} conversion The conversion specification object.
 * @return {string} Returns the formatted string.
 */

function float(replacement, conversion) {
  var replacementNumber = parseFloat(replacement);
  var formattedReplacement = void 0;
  if (isNaN(replacementNumber)) {
    replacementNumber = 0;
  }
  var precision = (0, _coerce_to_number2.default)(conversion.precision, 6);
  switch (conversion.typeSpecifier) {
    case _const2.default.TYPE_FLOAT:
      formattedReplacement = replacementNumber.toFixed(precision);
      break;
    case _const2.default.TYPE_FLOAT_SCIENTIFIC:
      formattedReplacement = replacementNumber.toExponential(precision);
      break;
    case _const2.default.TYPE_FLOAT_SCIENTIFIC_UPPERCASE:
      formattedReplacement = replacementNumber.toExponential(precision).toUpperCase();
      break;
    case _const2.default.TYPE_FLOAT_SHORT:
    case _const2.default.TYPE_FLOAT_SHORT_UPPERCASE:
      formattedReplacement = formatFloatAsShort(replacementNumber, precision, conversion);
      break;
  }
  formattedReplacement = (0, _add_sign_to_formatted_number2.default)(replacementNumber, formattedReplacement, conversion);
  return (0, _coerce_to_string2.default)(formattedReplacement);
}

/**
 * Formats the short float.
 *
 * @ignore
 * @param  {number} replacementNumber The number to format.
 * @param  {number} precision The precision to format the float.
 * @param  {ConversionSpecification} conversion The conversion specification object.
 * @return {string}  Returns the formatted short float.
 */
function formatFloatAsShort(replacementNumber, precision, conversion) {
  if (replacementNumber === 0) {
    return '0';
  }
  var nonZeroPrecision = precision === 0 ? 1 : precision;
  var formattedReplacement = replacementNumber.toPrecision(nonZeroPrecision).replace(_const3.REGEXP_TRAILING_ZEROS, '');
  if (conversion.typeSpecifier === _const2.default.TYPE_FLOAT_SHORT_UPPERCASE) {
    formattedReplacement = formattedReplacement.toUpperCase();
  }
  return formattedReplacement;
}
module.exports = exports['default'];